# Cats GMO

***catsgmo*** is one of the python library for [cats project](https://finance.rescala.jp/?page_id=204).

## Feature
***catsgmo*** provides API of GMOクリック証券(GMO CLICK Securities, Inc).

Supports:

1. [株価指数バイナリーオプション デモ取引](https://www.click-sec.com/corp/guide/ixop/demo/)

## Demo
### demo1
![catsgmo_1](https://user-images.githubusercontent.com/46471006/71720241-55d74500-2e64-11ea-9d0d-43eb7b14a430.gif)


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install catsgmo
```

## Usage

```python
tbd = "TBD"
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)